==> forms-v5.2.1.tar.gz: forms/l10n/lv.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Veidlapas",
    "Nextcloud Forms" : "Nextcloud veidlapas",
    "No" : "Nē",
    "Yes" : "Jā",
    "Copy" : "Kopēt",
    "Forms including questions and submissions" : "Veidlapas ar jautājumiem un iesniegšanu",
    "An error occurred while loading the forms list" : "Veidlapu saraksta ielādēšanas laikā atgadījās kļūda",
    "Your forms" : "Tavas veidlapas",
    "Shared with you" : "Koplietots ar jums",
    "Archived forms" : "Arhivētās veidlapas",
    "Loading forms …" : "Ielādē veidlapas…",
    "No forms created yet" : "Vēl nav izveidota neviena veidlapa",
    "Select groups" : "Atlasīt grupas",
    "Results" : "Rezultāti",
    "Cancel" : "Atcelt",
    "Required" : "Nepieciešams",
    "Delete" : "Izdzēst",
    "Uploading …" : "Augšupielādē…",
    "Other" : "Cits",
    "never" : "nekad",
    "Set expiration date" : "Iestatīt derīguma beigu datumu",
    "Closed forms do not accept new submissions." : "Aizvērtās veidlapās netiek pieņemti jauni iesniegumi.",
    "Archived forms do not accept new submissions and can not be modified." : "Aizvērtās formās netiek pieņemti jauni iesniegumi, un tās nevar mainīt.",
    "Group" : "Grupa",
    "Team" : "Komanda",
    "Permissions" : "Atļaujas",
    "Share link" : "Koplietot saiti",
    "Copy to clipboard" : "Kopēt starpliktuvē",
    "Show QR code" : "Parādīt kvadrātkodu",
    "Remove link" : "Noņemt saiti",
    "Internal link" : "Iekšējā saite",
    "View" : "Skats",
    "Edit" : "Labot",
    "View mode" : "Skatīšanās režīms",
    "Share" : "Koplietot",
    "Description" : "Apraksts",
    "Summary" : "Kopsavilkums",
    "Linked file is not available, would you like to link a new file?" : "Sasaistītā datne nav pieejama. Sasaistīt jaunu datni?",
    "Download" : "Lejupielādēt",
    "Search" : "Meklēt",
    "Results of submitted forms will show up here" : "Šeit tiks parādīts iesniegto veidlapu apkopojums",
    "Sharing" : "Koplietošana",
    "Settings" : "Iestatījumi",
    "Submit" : "Iesniegt",
    "Clear" : "Notīrīt",
    "The form has changed since your last visit. Do you want to clear all answers?" : "Veidlapa kopš pēdējā apmeklējuma ir mainījusies. Vai notīrīt visas atbildes?",
    "No recommendations. Start typing." : "Nav ieteikumu. Jāsāk rakstīt.",
    "No elements found." : "Elementi netika atrasti.",
    "File" : "Datne",
    "Date" : "Datums",
    "Pick a date" : "Izvēlēties datumu",
    "Time" : "Laiks",
    "Pick a time" : "Izvēlēties laiku",
    "Color" : "Krāsa",
    "Image" : "Attēli",
    "Document" : "Dokuments",
    "Presentation" : "Prezentācija",
    "Spreadsheet" : "Izklājlapa",
    "Text" : "Teksts",
    "Phone number" : "Tālruņa numurs",
    "Email address" : "E-pasta adrese"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> forms-v5.2.2.tar.gz: forms/l10n/lv.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Veidlapas",
    "Nextcloud Forms" : "Nextcloud veidlapas",
    "No" : "Nē",
    "Yes" : "Jā",
    "Copy" : "Kopēt",
    "Forms including questions and submissions" : "Veidlapas ar jautājumiem un iesniegšanu",
    "An error occurred while loading the forms list" : "Veidlapu saraksta ielādēšanas laikā atgadījās kļūda",
    "Your forms" : "Tavas veidlapas",
    "Shared with you" : "Koplietots ar jums",
    "Archived forms" : "Arhivētās veidlapas",
    "No forms created yet" : "Vēl nav izveidota neviena veidlapa",
    "Select groups" : "Atlasīt grupas",
    "Results" : "Rezultāti",
    "Cancel" : "Atcelt",
    "Required" : "Nepieciešams",
    "Delete" : "Izdzēst",
    "Other" : "Cits",
    "never" : "nekad",
    "Set expiration date" : "Iestatīt derīguma beigu datumu",
    "Closed forms do not accept new submissions." : "Aizvērtās veidlapās netiek pieņemti jauni iesniegumi.",
    "Archived forms do not accept new submissions and can not be modified." : "Aizvērtās formās netiek pieņemti jauni iesniegumi, un tās nevar mainīt.",
    "Group" : "Grupa",
    "Team" : "Komanda",
    "Permissions" : "Atļaujas",
    "Share link" : "Koplietot saiti",
    "Copy to clipboard" : "Kopēt starpliktuvē",
    "Show QR code" : "Parādīt kvadrātkodu",
    "Remove link" : "Noņemt saiti",
    "Internal link" : "Iekšējā saite",
    "View" : "Skats",
    "Edit" : "Labot",
    "View mode" : "Skatīšanās režīms",
    "Share" : "Koplietot",
    "Description" : "Apraksts",
    "Summary" : "Kopsavilkums",
    "Linked file is not available, would you like to link a new file?" : "Sasaistītā datne nav pieejama. Sasaistīt jaunu datni?",
    "Download" : "Lejupielādēt",
    "Search" : "Meklēt",
    "Results of submitted forms will show up here" : "Šeit tiks parādīts iesniegto veidlapu apkopojums",
    "Sharing" : "Koplietošana",
    "Settings" : "Iestatījumi",
    "Submit" : "Iesniegt",
    "Clear" : "Notīrīt",
    "The form has changed since your last visit. Do you want to clear all answers?" : "Veidlapa kopš pēdējā apmeklējuma ir mainījusies. Vai notīrīt visas atbildes?",
    "No recommendations. Start typing." : "Nav ieteikumu. Jāsāk rakstīt.",
    "No elements found." : "Elementi netika atrasti.",
    "File" : "Datne",
    "Date" : "Datums",
    "Pick a date" : "Izvēlēties datumu",
    "Time" : "Laiks",
    "Pick a time" : "Izvēlēties laiku",
    "Color" : "Krāsa",
    "Image" : "Attēli",
    "Document" : "Dokuments",
    "Presentation" : "Prezentācija",
    "Spreadsheet" : "Izklājlapa",
    "Text" : "Teksts",
    "Phone number" : "Tālruņa numurs",
    "Email address" : "E-pasta adrese",
    "Loading forms …" : "Ielādē veidlapas…",
    "Uploading …" : "Augšupielādē…"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
